@@ -1,10 +1,13 @@
 /*	This file is part of the debugging module DEBUG.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: debug.h,v 1.5 2012-01-25 21:43:05 Gebruiker Exp $
+	$Id: debug.h,v 1.7 2013-05-12 09:58:34 Gebruiker Exp $
 */
 
-/*
-DEBUG defines one routine,
+#ifndef	_DEBUG_H_
+#define _DEBUG_H_
+
+/****
+The module DEBUG defines one routine,
 
 	extern void wr_info(const char *s, int b, int v);
 
@@ -24,6 +27,9 @@ and other nefarious program activity.
 
 Compiled without the -DDEBUG option wr_info does nothing. This allows easy
 switching off of the debugging feature by recompiling debug.c.
-*/
+****/
 
+/* Public entries */
 extern void wr_info(const char *s, int b, int v);
+
+#endif	/* _DEBUG_H_ */
