@@ -1,6 +1,6 @@
 /*	This file is part of the auxiliaries library.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: fname.h,v 1.8 2012-06-13 09:59:52 Gebruiker Exp $
+	$Id: fname.h,v 1.11 2013-05-12 13:21:24 Gebruiker Exp $
 */
 
 /*	Support for UNICODE file names */
@@ -21,7 +21,7 @@
 
       Fchar *Fnamecpy(Fchar *dest, Fchar *source);
       Fchar *Fnamecat(Fchar*, const Fchar*);
-      size_t Fnamelen(const Fchar*);
+      int Fnamelen(const Fchar*);
       int Fnamecmp(const Fchar*, const Fchar*);
 
       int Stat(const Fchar *fn, struct stat *st);
@@ -66,17 +66,19 @@
 #include	<sys/stat.h>
 #include	<dirent.h>
 
+/* Private entries */
 typedef _TCHAR Fchar;
 typedef _WDIR Dir_t;
 typedef struct _tdirent Dirent_t;
 
+/* Public entries */
 #define	Opendir		_topendir
 #define	Closedir	_tclosedir
 #define	Readdir		_treaddir
 
 #define	Fnamecpy	wcscpy
 #define	Fnamecat	wcscat
-#define	Fnamelen	wcslen
+#define	Fnamelen	(int)wcslen
 #define	Fnamecmp	wcscmp
 
 extern const char *Fname2str(const Fchar *fn);		/* transient! */
@@ -90,8 +92,10 @@ extern FILE *Fopen(const Fchar *fn, const char *rb);/* stream is still char* */
 
 #include	<sys/stat.h>
 #include	<dirent.h>
+#include	<string.h>
 
 /* life is simple */
+/* Public entries */
 typedef char Fchar;
 
 #define	Fnamecpy	strcpy
