@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: hash.c,v 2.18 2012-06-08 06:52:14 Gebruiker Exp $
+	$Id: hash.c,v 2.23 2014-01-27 20:50:50 Gebruiker Exp $
 */
 
 /*	Text is compared by comparing every substring to all substrings
@@ -32,6 +32,7 @@
 */
 
 #include	<stdio.h>
+#include	<stdint.h>
 
 #include	"system.par"
 #include	"debug.par"
@@ -39,6 +40,7 @@
 #include	"text.h"
 #include	"Malloc.h"
 #include	"error.h"
+#include	"any_int.h"
 #include	"token.h"
 #include	"language.h"
 #include	"token.h"
@@ -47,8 +49,8 @@
 #include	"hash.h"
 
 							/* MAIN ENTRIES */
-static unsigned int *forward_reference;		/* to be filled by Malloc() */
-static int n_forward_references;
+static size_t *forward_reference;		/* to be filled by Malloc() */
+static size_t n_forward_references;
 
 static void make_forward_references_hash1(void);
 static void make_forward_references_hash2(void);
@@ -65,8 +67,8 @@ Make_Forward_References(void) {
 
 	n_forward_references = Text_Length();
 	forward_reference =
-		(unsigned int *)Calloc(
-			n_forward_references, sizeof (unsigned int)
+		(size_t *)Calloc(
+			n_forward_references, sizeof (size_t)
 		);
 	make_forward_references_hash1();
 	make_forward_references_hash2();
@@ -75,9 +77,9 @@ Make_Forward_References(void) {
 #endif
 }
 
-unsigned int
-Forward_Reference(int i) {
-	if (i <= 0 || i >= n_forward_references) {
+size_t
+Forward_Reference(size_t i) {
+	if (i == 0 || i >= n_forward_references) {
 		fatal("internal error, bad forward reference");
 	}
 	return forward_reference[i];
@@ -94,7 +96,7 @@ Free_Forward_References(void) {
 	Min_Run_Size, which is a problem since the size of the object
 	we derive the hash value from IS equal to Min_Run_Size!
 	Therefore we base the hash function on a sample of at most
-	N_SAMPLES tokens from the input string; this works at least
+	N_SAMPLES tokens from the input string; this works just
 	as well in practice.
 */
 
@@ -111,30 +113,56 @@ Free_Forward_References(void) {
 #define	OPERATION	+ 613 *
 */
 
-static unsigned int *last_index;
-static unsigned int hash_table_size;
-static int sample_pos[N_SAMPLES];
+static size_t *last_index;
+static size_t hash_table_size;
+/* positions where the N_SAMPLES samples can be found: */
+static size_t sample_pos[N_SAMPLES];
 
-static unsigned int
-prime[] = {		/* lots of hopefully suitable primes */
-	10639,
-	21283,
-	42571,
-	85147,
-	170227,
-	340451,
-	680959,
-	1361803,
-	2723599,
-	5447171,
-	10894379,
-	21788719,
-	43577399,
-	87154759,
-	174309383,
-	348618827,
-	697237511,
-	1394475011
+/* The prime numbers of the form 4 * i + 3 for some i, all greater
+   than twice the previous one and smaller than 2^40 (for now).
+*/
+static const uint64_t prime[] = {
+#if 0
+	3,
+	7,
+	19,
+	43,
+	103,
+	211,
+	431,
+	863,
+	1747,
+	3499,
+	7019,
+#endif
+	14051,
+	28111,
+	56239,
+	112507,
+	225023,
+	450067,
+	900139,
+	1800311,
+	3600659,
+	7201351,
+	14402743,
+	28805519,
+	57611039,
+	115222091,
+	230444239,
+	460888499,
+	921777067,
+	1843554151,
+	UINT64_C (3687108307),
+	UINT64_C (7374216631),
+	UINT64_C (14748433279),
+	UINT64_C (29496866579),
+	UINT64_C (58993733159),
+	UINT64_C (117987466379),
+	UINT64_C (235974932759),
+	UINT64_C (471949865531),
+	UINT64_C (943899731087)
+	/* 2^40= 1099511627776 */
 };
 
 static void
@@ -152,8 +180,8 @@ init_hash_table(void) {
 	last_index = 0;
 	while (!last_index && n >= 0) {
 		hash_table_size = prime[n];
-		last_index = (unsigned int *)
-			TryCalloc(hash_table_size, sizeof (unsigned int));
+		last_index = (size_t *)
+			TryCalloc(hash_table_size, sizeof (size_t));
 		n--;
 	}
 	if (!last_index) {
@@ -170,7 +198,7 @@ init_hash_table(void) {
 	}
 }
 
-static int hash1(const Token *);
+static size_t hash1(const Token *);
 
 static void
 make_forward_references_hash1(void) {
@@ -181,7 +209,7 @@ make_forward_references_hash1(void) {
 	/* set up the forward references using the last_index hash table */
 	for (n = 0; n < Number_Of_Texts; n++) {
 		struct text *txt = &Text[n];
-		unsigned int j;
+		size_t j;
 
 		for (	/* all pos'ns in txt except the last Min_Run_Size-1 */
 			j = txt->tx_start;			/* >= 1 */
@@ -189,7 +217,7 @@ make_forward_references_hash1(void) {
 			j++
 		) {
 			if (May_Be_Start_Of_Run(Token_Array[j])) {
-				int h = hash1(&Token_Array[j]);
+				size_t h = hash1(&Token_Array[j]);
 
 				if (last_index[h]) {
 					forward_reference[last_index[h]] = j;
@@ -205,31 +233,39 @@ make_forward_references_hash1(void) {
 #endif	/* DB_FORW_REF */
 }
 
-static int
+static size_t
 hash1(const Token *p) {
 	/*	hash1(p) returns the hash code of Min_Run_Size
 		tokens starting at p; caller guarantees that there
 		are at least Min_Run_Size tokens.
 	*/
-	int32 h_val;
+	uint64_t h_val;
 	int n;
 
 	h_val = 0;
 	for (n = 0; n < N_SAMPLES; n++) {
-		h_val = (h_val << 1) OPERATION Token2int(p[sample_pos[n]]);
-		if (h_val & (1<<31)) {
-			h_val ^= (1<<31|1);
+		h_val = (h_val << 2) OPERATION Token2int(p[sample_pos[n]]);
+		if (h_val & (1ULL<<63)) {
+			h_val ^= (1ULL<<63|1);
 		}
 	}
 
-	return h_val % hash_table_size;
+#ifdef	DB_HASH
+	/* reduce h_val to the type yielded by hash1(), and print the
+	   result in a responsible way
+	*/
+	size_t h = (size_t) (h_val % hash_table_size);
+	fprintf(Debug_File, "hash1 = %s\n", any_uint2string(h, 0));
+#endif	/* DB_HASH */
+
+	return (size_t) (h_val % hash_table_size);
 }
 
-static int hash2(const Token *);
+static size_t hash2(const Token *);
 
 static void
 make_forward_references_hash2(void) {
-	unsigned int i;
+	size_t i;
 
 	/*	Clean out spurious matches, by a quadratic algorithm.
 		Note that we do not want to eliminate overlapping
@@ -237,8 +273,8 @@ make_forward_references_hash2(void) {
 		wrong copy.
 	*/
 	for (i = 0; i+Min_Run_Size < Text_Length(); i++) {
-		unsigned int j = i;
-		int h2 = hash2(&Token_Array[i]);
+		size_t j = i;
+		size_t h2 = hash2(&Token_Array[i]);
 
 		/*	Find the first token sequence in the chain
 			with same secondary hash code.
@@ -259,12 +295,32 @@ make_forward_references_hash2(void) {
 #endif	/* DB_FORW_REF */
 }
 
-static int
+static size_t
 hash2(const Token *p) {
 	/*	A simple-minded hashing for the secondary sweep;
-		first and last token combined in a short int.
+		sample first, middle, and last token, and on 64-bit systems
+		also two tokens from in between these.
 	*/
-	return (Token2int(p[0]) << 8) + Token2int(p[Min_Run_Size-1]);
+	int pos_last_sample = N_SAMPLES - 1;
+	uint64_t h_val = 0;
+	h_val ^= ((uint64_t)Token2int(p[sample_pos[0]])) << 0;
+	h_val ^= ((uint64_t)Token2int(p[sample_pos[pos_last_sample]])) << 16;
+	h_val ^= ((uint64_t)Token2int(p[sample_pos[pos_last_sample/2]])) << 24;
+	h_val ^= ((uint64_t)Token2int(p[sample_pos[pos_last_sample*1/4]]))<<32;
+	h_val ^= ((uint64_t)Token2int(p[sample_pos[pos_last_sample*3/4]]))<<48;
+	/* the last two are ignored on a 32-bit system */
+	h_val *= 2147483647;
+	h_val &= 017777777777;
+
+#ifdef	DB_HASH
+	/* reduce h_val to the type yielded by hash2(), and print the
+	   result in a responsible way
+	*/
+	size_t h = (size_t)h_val;
+	fprintf(Debug_File, "hash2 = %s\n", any_uint2string(h, 0));
+#endif	/* DB_HASH */
+
+	return (size_t)h_val;
 }
 
 #ifdef	DB_FORW_REF
@@ -273,20 +329,22 @@ static int hash3(const Token *, const Token *);
 
 static void
 db_print_forward_references(void) {
-	unsigned int n;
-	unsigned int *printed_at =
-		(unsigned int *)Calloc(Text_Length(), sizeof (unsigned int));
+	size_t n;
+	size_t *printed_at =
+		(size_t *)Calloc(Text_Length(), sizeof (size_t));
 
 	for (n = 1; n < Text_Length(); n++) {
-		unsigned int fw = forward_reference[n];
+		size_t fw = forward_reference[n];
 		if (fw == 0) continue;
-		fprintf(Debug_File, "FWR[%d]:", n);
+		fprintf(Debug_File, "FWR[%s]:", any_uint2string(n, 0));
 		if (printed_at[fw]) {
-			fprintf(Debug_File, " see %d", printed_at[fw]);
+			fprintf(Debug_File, " see %s",
+				any_uint2string(printed_at[fw], 0));
 		}
 		else {
 			while (fw) {
-				fprintf(Debug_File, " %d", fw);
+				fprintf(Debug_File, " %s",
+					any_uint2string(fw, 0));
 				printed_at[fw] = n;
 				fw = forward_reference[fw];
 			}
@@ -298,13 +356,13 @@ db_print_forward_references(void) {
 
 static void
 make_forward_references_hash3(void) {
-	unsigned int i;
+	size_t i;
 
 	/* Do a third hash to check up on the previous two */
 
 	/* This time we use a genuine compare */
 	for (i = 0; i+Min_Run_Size < Text_Length(); i++) {
-		unsigned int j = i;
+		size_t j = i;
 
 		while (	/* there is still a forward reference */
 			(j = forward_reference[j])
@@ -323,7 +381,7 @@ make_forward_references_hash3(void) {
 static int
 hash3(const Token *p, const Token *q) {
 	/* a full comparison for the tertiary sweep */
-	int n;
+	size_t n;
 
 	for (n = 0; n < Min_Run_Size; n++) {
 		if (!Token_EQ(p[n], q[n])) return 0;
@@ -331,11 +389,17 @@ hash3(const Token *p, const Token *q) {
 	return 1;
 }
 
-static int
-db_frw_chain(int n, char *crossed_out) {
-	int chain_len = -1;
-		/* if there are two values, the chain length is still 1 */
-	int fw;
+static size_t
+db_frw_chain(size_t n, char *crossed_out) {
+	if (forward_reference[n] == 0) {
+		fprintf(Debug_File,
+			">>>> db_frw_chain() forward_reference[n] == 0 <<<<\n"
+		);
+		return 0;
+	}
+
+	size_t n_entries = 0;
+	size_t fw;
 
 	for (fw = n; fw; fw = forward_reference[fw]) {
 		if (crossed_out[fw]) {
@@ -343,23 +407,26 @@ db_frw_chain(int n, char *crossed_out) {
 				">>>> error: forward references cross <<<<\n"
 			);
 		}
-		chain_len++;
+		n_entries++;
 		crossed_out[fw] = 1;
 	}
-	fprintf(Debug_File, "chain_start = %d, chain_len = %d\n", n, chain_len);
+	fprintf(Debug_File, "chain_start = %s, n_entries = %s\n",
+		any_uint2string(n, 0), any_uint2string(n_entries, 0));
 
-	return chain_len;
+	/* return chain length */
+	return n_entries - 1;
 }
 
 static void
 db_forward_references(const char *msg) {
-	int n;
-	int n_frw_chains = 0;		/* number of forward ref. chains */
-	int tot_frwc_len = 0;
+	size_t n;
+	size_t n_frw_chains = 0;	/* number of forward ref. chains */
+	size_t tot_frwc_len = 0;
 	char *crossed_out;
 
 	fprintf(Debug_File, "\n\n**** DB_FORWARD_REFERENCES, %s ****\n", msg);
-	fprintf(Debug_File, "hash_table_size = %u\n", hash_table_size);
+	fprintf(Debug_File, "hash_table_size = %s\n",
+		any_uint2string(hash_table_size, 0));
 	fprintf(Debug_File, "N_SAMPLES = %d\n", N_SAMPLES);
 
 	crossed_out = (char *)Calloc(Text_Length(), sizeof (char));
@@ -389,8 +456,10 @@ db_forward_references(const char *msg) {
 	Free((char *)crossed_out);
 
 	fprintf(Debug_File,
-		"text length = %u, # forward chains = %d, total frw chain length = %d\n\n",
-		Text_Length(), n_frw_chains, tot_frwc_len
+		"text length = %s, # forward chains = %s, total frw chain length = %s\n\n",
+		any_uint2string(Text_Length(), 0),
+		any_uint2string(n_frw_chains, 0),
+		any_uint2string(tot_frwc_len, 0)
 	);
 }
 
