@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: hash.h,v 1.3 2012-05-13 09:05:49 Gebruiker Exp $
+	$Id: hash.h,v 1.4 2013-04-28 16:30:40 Gebruiker Exp $
 */
 
 /*	Creating and consulting forward_reference[], used to speed up
@@ -9,4 +9,4 @@
 
 extern void Make_Forward_References(void);
 extern void Free_Forward_References(void);
-extern unsigned int Forward_Reference(int i);
+extern size_t Forward_Reference(size_t i);
