@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: runs.c,v 1.6 2012-06-05 09:58:54 Gebruiker Exp $
+	$Id: runs.c,v 1.7 2014-01-26 21:52:59 Gebruiker Exp $
 */
 
 #include	"sim.h"
@@ -37,18 +37,23 @@ db_run_info(const char *msg, const struct run *run, int lines_too) {
 	fprintf(Debug_File, "File %s / file %s:\n",
 		cnk0->ch_text->tx_fname, cnk1->ch_text->tx_fname
 	);
-	fprintf(Debug_File, "from %s %u/%u to %u/%u:", token_name,
-		cnk0->ch_first.ps_tk_cnt, cnk1->ch_first.ps_tk_cnt,
-		cnk0->ch_last.ps_tk_cnt, cnk1->ch_last.ps_tk_cnt
+	fprintf(Debug_File, "from %s %s/%s to %s/%s:", token_name,
+		size_t2string(cnk0->ch_first.ps_tk_cnt),
+		size_t2string(cnk1->ch_first.ps_tk_cnt),
+		size_t2string(cnk0->ch_last.ps_tk_cnt),
+		size_t2string(cnk1->ch_last.ps_tk_cnt)
 	);
 	if (lines_too) {
-		fprintf(Debug_File, " from lines %u/%u to %u/%u:",
-			cnk0->ch_first.ps_nl_cnt, cnk1->ch_first.ps_nl_cnt,
-			cnk0->ch_last.ps_nl_cnt, cnk1->ch_last.ps_nl_cnt
+		fprintf(Debug_File, " from lines %s/%s to %s/%s:",
+			size_t2string(cnk0->ch_first.ps_nl_cnt),
+			size_t2string(cnk1->ch_first.ps_nl_cnt),
+			size_t2string(cnk0->ch_last.ps_nl_cnt),
+			size_t2string(cnk1->ch_last.ps_nl_cnt)
 		);
 	}
-	fprintf(Debug_File, " %u %s%s\n",
-		run->rn_size, token_name, (run->rn_size == 1 ? "" : "s")
+	fprintf(Debug_File, " %s %s%s\n",
+		size_t2string(run->rn_size),
+		token_name, (run->rn_size == 1 ? "" : "s")
 	);
 }
 
